@@ -1,4 +1,4 @@
-/* $Id: blkmem.h,v 1.5 2010/06/13 12:37:40 bzfkocht Exp $ */
+/* $Id: blkmem.h,v 1.8 2011/10/25 08:18:01 bzfkocht Exp $ */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*                                                                           */
 /*   File....: blkmem.h                                                      */
@@ -8,7 +8,7 @@
 /*                                                                           */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*
- * Copyright (C) 2007-2010 by Thorsten Koch <koch@zib.de>
+ * Copyright (C) 2007-2011 by Thorsten Koch <koch@zib.de>
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -22,15 +22,22 @@
  * 
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifndef _BLKMEM_H_
 #define _BLKMEM_H_
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 extern void  blk_init(void);
 extern void  blk_exit(void);
 extern void* blk_alloc(int size);
 extern void  blk_free(void* p, int size);
 
+#ifdef __cplusplus
+}
+#endif
 #endif /* _BLKMEM_H_ */
