@@ -1,4 +1,4 @@
-/* $Id: bool.h,v 1.6 2010/06/13 12:37:40 bzfkocht Exp $ */
+/* $Id: bool.h,v 1.9 2011/10/25 08:18:01 bzfkocht Exp $ */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*                                                                           */
 /*   File....: bool.h                                                        */
@@ -8,7 +8,7 @@
 /*                                                                           */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*
- * Copyright (C) 2003-2010 by Thorsten Koch <koch@zib.de>
+ * Copyright (C) 2003-2011 by Thorsten Koch <koch@zib.de>
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -22,11 +22,15 @@
  * 
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 #ifndef _BOOL_H_
 #define _BOOL_H_
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 typedef int            Bool;
 
 #ifndef TRUE
@@ -36,4 +40,7 @@ typedef int            Bool;
 #define FALSE           ((Bool)0)
 #endif
 
+#ifdef __cplusplus
+}
+#endif
 #endif /* _BOOL_H_ */
