@@ -1,4 +1,4 @@
-/* $Id: code.h,v 1.25 2010/06/13 12:37:40 bzfkocht Exp $ */
+/* $Id: code.h,v 1.28 2011/10/25 08:18:01 bzfkocht Exp $ */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*                                                                           */
 /*   File....: code.h                                                        */
@@ -8,7 +8,7 @@
 /*                                                                           */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*
- * Copyright (C) 2001-2010 by Thorsten Koch <koch@zib.de>
+ * Copyright (C) 2001-2011 by Thorsten Koch <koch@zib.de>
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -22,7 +22,7 @@
  * 
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifndef _CODE_H_
@@ -40,6 +40,10 @@
 #error "Need to include mme.h before code.h"
 #endif
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 /*lint -sem(        code_new_inst, 1p == 1 && 2n >= 0, @p == 1) */
 extern CodeNode*    code_new_inst(Inst inst, int childs, ...);
 /*lint -sem(        code_new_numb, custodial(1), 1p == 1, @p == 1) */
@@ -214,6 +218,9 @@ extern Define*      code_eval_child_define(const CodeNode* node, int no);
 /*lint -sem(        code_eval_child_bound, 1p == 1 && 2n >= 0) */
 extern const Bound* code_eval_child_bound(const CodeNode* node, int no);
 
+#ifdef __cplusplus
+}
+#endif
 #endif /* _CODE_H_ */
 
 
