@@ -1,4 +1,4 @@
-/* $Id: conname.c,v 1.17 2010/06/13 12:37:40 bzfkocht Exp $ */
+/* $Id: conname.c,v 1.20 2011/10/25 08:18:01 bzfkocht Exp $ */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*                                                                           */
 /*   File....: conname.c                                                     */
@@ -8,7 +8,7 @@
 /*                                                                           */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*
- * Copyright (C) 2001-2010 by Thorsten Koch <koch@zib.de>
+ * Copyright (C) 2001-2011 by Thorsten Koch <koch@zib.de>
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -22,7 +22,7 @@
  * 
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #include <stdio.h>
@@ -41,13 +41,15 @@
 #include "elem.h"
 #include "tuple.h"
 #include "local.h"
+#include "stmt.h"
+#include "prog.h"
 #include "xlpglue.h"
 #include "conname.h"
 
 static char*        cpfix  = NULL;
 static int          count  = 1;
 static char*        cname  = NULL;
-static unsigned int clen   = 0;
+static size_t       clen   = 0;
 static ConNameForm  cform  = CON_FORM_NAME;
 
 void conname_format(ConNameForm format)
@@ -93,18 +95,18 @@ Bool conname_set(const char* prefix)
    strcpy(cname, cpfix);
    strcat(cname, "_1");
 
-   if (xlp_conname_exists(cname))
+   if (xlp_conname_exists(prog_get_lp(), cname))
       return FALSE;
 
    strcat(cname, "_a_0");
 
-   return !xlp_conname_exists(cname);
+   return !xlp_conname_exists(prog_get_lp(), cname);
 }
 
 const char* conname_get()
 {
-   char*        localstr;
-   unsigned int newlen;
+   char*  localstr;
+   size_t newlen;
    
    assert(cpfix != NULL);
    assert(cname != NULL);
