@@ -1,4 +1,4 @@
-/* $Id: gmpmisc.h,v 1.6 2010/06/13 12:37:40 bzfkocht Exp $ */
+/* $Id: gmpmisc.h,v 1.9 2011/10/25 08:18:01 bzfkocht Exp $ */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*                                                                           */
 /*   File....: gmpmisc.c                                                     */
@@ -8,7 +8,7 @@
 /*                                                                           */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*
- * Copyright (C) 2003-2010 by Thorsten Koch <koch@zib.de>
+ * Copyright (C) 2003-2011 by Thorsten Koch <koch@zib.de>
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -22,7 +22,7 @@
  * 
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 #ifndef _GMPMISC_H_
 #define _GMPMISC_H_
@@ -34,6 +34,10 @@
 #error "Need to include bool.h before gmpmisc.h"
 #endif
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 extern mpq_t const_zero;
 extern mpq_t const_one;
 extern mpq_t const_minus_one;
@@ -45,4 +49,7 @@ extern void gmp_print_mpq(FILE* fp, const mpq_t qval);
 extern void gmp_init(Bool verb, Bool with_management);
 extern void gmp_exit(void);
 
+#ifdef __cplusplus
+}
+#endif
 #endif /* _GMPMISC_H */
