@@ -1,4 +1,4 @@
-/* $Id: hash.c,v 1.32 2010/06/13 12:37:40 bzfkocht Exp $ */
+/* $Id: hash.c,v 1.35 2011/10/25 08:18:01 bzfkocht Exp $ */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*                                                                           */
 /*   File....: hash.c                                                        */
@@ -8,7 +8,7 @@
 /*                                                                           */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*
- * Copyright (C) 2001-2010 by Thorsten Koch <koch@zib.de>
+ * Copyright (C) 2001-2011 by Thorsten Koch <koch@zib.de>
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -22,7 +22,7 @@
  * 
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #include <stdio.h>
@@ -41,6 +41,7 @@
 #include "set.h"
 #include "symbol.h"
 #include "entry.h"
+#include "mono.h"
 #include "hash.h"
 
 #define HASH_SID      0x48617368
@@ -62,6 +63,7 @@ struct hash_element
       const Entry* entry;
       SetElemIdx   elem_idx;
       const Numb*  numb;
+      const Mono*  mono;
    } value;
    HElem* next;
 };
@@ -142,7 +144,8 @@ Bool hash_is_valid(const Hash* hash)
 {
    return ((hash != NULL)
       && (hash->type == HASH_TUPLE || hash->type == HASH_ENTRY
-       || hash->type == HASH_ELEM_IDX || hash->type == HASH_NUMB)
+       || hash->type == HASH_ELEM_IDX || hash->type == HASH_NUMB
+       || hash->type == HASH_MONO)
       && SID_ok(hash, HASH_SID));
 }
 
@@ -200,6 +203,23 @@ void hash_add_numb(Hash* hash, const Numb* numb)
    hash->elems++;
 }
 
+void hash_add_mono(Hash* hash, const Mono* mono)
+{
+   HElem*       he = blk_alloc(sizeof(*he));
+   unsigned int hcode;
+
+   assert(hash_is_valid(hash));
+   assert(mono_is_valid(mono));
+   assert(hash->type == HASH_MONO);
+   assert(he != NULL);
+   
+   hcode               = mono_hash(mono) % hash->size;
+   he->value.mono      = mono;
+   he->next            = hash->bucket[hcode];
+   hash->bucket[hcode] = he;
+   hash->elems++;
+}
+
 Bool hash_has_tuple(const Hash* hash, const Tuple* tuple)
 {
    unsigned int hcode = tuple_hash(tuple) % hash->size;
@@ -269,6 +289,30 @@ const Entry* hash_lookup_entry(const Hash* hash, const Tuple* tuple)
    return he->value.entry;
 }
 
+/* Liefert NULL wenn nicht gefunden.
+ */
+const Mono* hash_lookup_mono(const Hash* hash, const Mono* mono)
+{
+   unsigned int hcode = mono_hash(mono) % hash->size;
+   HElem*       he;
+   
+   assert(hash_is_valid(hash));
+   assert(mono_is_valid(mono));
+
+   for(he = hash->bucket[hcode]; he != NULL; he = he->next)
+      if (mono_equal(he->value.mono, mono))
+         break;
+
+   if (he == NULL)
+      return NULL;
+
+   assert(he != NULL);
+
+   assert(mono_is_valid(he->value.mono));
+
+   return he->value.mono;
+}
+
 void hash_add_elem_idx(Hash* hash, const Elem* elem, int idx)
 {
    HElem*       he = blk_alloc(sizeof(*he));
