@@ -1,4 +1,4 @@
-/* $Id: iread.c,v 1.36 2010/06/13 12:37:40 bzfkocht Exp $ */
+/* $Id: iread.c,v 1.39 2011/09/18 10:22:35 bzfkocht Exp $ */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*                                                                           */
 /*   File....: iread.c                                                       */
@@ -8,7 +8,7 @@
 /*                                                                           */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*
- * Copyright (C) 2001-2010 by Thorsten Koch <koch@zib.de>
+ * Copyright (C) 2001-2011 by Thorsten Koch <koch@zib.de>
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -22,7 +22,7 @@
  * 
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 #include <stdio.h>
 #include <stdlib.h>
@@ -666,10 +666,10 @@ CodeNode* i_read(CodeNode* self)
    MFP*        fp;
    char*       s;
    char*       buf;
-   char*       field[MAX_FIELDS];
+   char**      field;
    int         fields;
-   int         param_field[MAX_FIELDS];  /* template parameter field number */
-   int         param_type [MAX_FIELDS];  /* template parameter field type */
+   int*        param_field;  /* template parameter field number */
+   int*        param_type;  /* template parameter field type */
    Bool        is_tuple_list;
    Bool        is_streaming;
    int         hi_field_no;
@@ -687,6 +687,14 @@ CodeNode* i_read(CodeNode* self)
    Trace("i_read");
    
    assert(code_is_valid(self));
+
+   field       = malloc(MAX_FIELDS * sizeof(*field));
+   param_field = malloc(MAX_FIELDS * sizeof(*param_field));
+   param_type  = malloc(MAX_FIELDS * sizeof(*param_type));
+
+   assert(field       != NULL);
+   assert(param_field != NULL);
+   assert(param_type  != NULL);
    
    rdef     = code_eval_child_rdef(self, 0);
    use      = rdef_get_use(rdef);
@@ -791,9 +799,12 @@ CodeNode* i_read(CodeNode* self)
          {
             if (fields == MAX_FIELDS)
             {
-               fprintf(stderr, "--- Warning 213: More than %d input fields in line %d of %s\n",
-                  fields, line, filename);
-               code_errmsg(self);
+               if (stmt_trigger_warning(213))
+               {
+                  fprintf(stderr, "--- Warning 213: More than %d input fields in line %d of %s\n",
+                     fields, line, filename);
+                  code_errmsg(self);
+               }
             }
             if (is_tuple_list)
                list = process_tuple_stream(self, list, rdef, line,
@@ -835,9 +846,11 @@ CodeNode* i_read(CodeNode* self)
       }
       tuple_free(tuple);
 
-      //fprintf(stderr, "*** Error 158: Read from file found no data\n");
-      //code_errmsg(self);
-      //zpl_exit(EXIT_FAILURE);
+      /*
+        fprintf(stderr, "*** Error 158: Read from file found no data\n");
+        code_errmsg(self);
+        zpl_exit(EXIT_FAILURE);
+      */
    }
    code_value_list(self, list);
 
@@ -846,6 +859,9 @@ CodeNode* i_read(CodeNode* self)
    
    free(comment);
    free(filename);
+   free(param_type);
+   free(param_field);
+   free(field);
    
    return self;
 }
