@@ -1,4 +1,4 @@
-/* $Id: load.c,v 1.38 2010/06/13 12:37:40 bzfkocht Exp $ */
+/* $Id: load.c,v 1.41 2011/09/18 10:22:35 bzfkocht Exp $ */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*                                                                           */
 /*   File....: load.c                                                        */
@@ -8,7 +8,7 @@
 /*                                                                           */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*
- * Copyright (C) 2001-2010 by Thorsten Koch <koch@zib.de>
+ * Copyright (C) 2001-2011 by Thorsten Koch <koch@zib.de>
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -22,7 +22,7 @@
  * 
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #include <stdio.h>
@@ -111,7 +111,7 @@ static char* get_line(char** buf, int* size, const MFP* fp, int* lineno)
          if (cnt > 0)
          {
             (*buf)[cnt] = '\0';
-            if (verbose > VERB_QUIET)
+            if (stmt_trigger_warning(162))
                fprintf(stderr, "--- Warning 162: Line %d: Trailing \"%.20s\" ignored\n",
                   *lineno, *buf);
          }
@@ -138,8 +138,9 @@ static char* get_line(char** buf, int* size, const MFP* fp, int* lineno)
       if (!in_string && (c == '#'))
       {
          skip_comment(fp, lineno);
-         //do { c = mio_getc(fp); } while((c != EOF) && (c != '\n'));
-         //(*lineno)++;
+         /* do { c = mio_getc(fp); } while((c != EOF) && (c != '\n'));
+           (*lineno)++;
+         */
          continue;
       }
       (*buf)[cnt++] = (char)c;
