@@ -1,4 +1,4 @@
-/* $Id: mme.h,v 1.96 2010/09/30 17:41:46 bzfkocht Exp $ */
+/* $Id: mme.h,v 1.100 2011/10/25 08:18:02 bzfkocht Exp $ */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*                                                                           */
 /*   File....: mme.h                                                         */
@@ -8,7 +8,7 @@
 /*                                                                           */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*
- * Copyright (C) 2001-2010 by Thorsten Koch <koch@zib.de>
+ * Copyright (C) 2001-2011 by Thorsten Koch <koch@zib.de>
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -22,7 +22,7 @@
  * 
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 #ifndef _MME_H_
 #define _MME_H_
@@ -31,7 +31,7 @@
 extern "C" {
 #endif
 
-#define ZIMPL_VERSION  310
+#define ZIMPL_VERSION  320
 
 /* the following is not in code.h because code.h needs mme.h anyway,
  * but we also need these declaratons.
@@ -56,11 +56,14 @@ typedef CodeNode*              (*Inst)(CodeNode* self);
 typedef struct entry             Entry;
 typedef union set                Set;
 typedef union set_iter           SetIter;
-typedef enum set_check_type      SetCheckType;
 
 typedef struct list_element      ListElem;
 typedef struct list              List;
 
+typedef enum   var_type      VarType;  /* From ratlptypes.h */
+typedef struct mono          Mono;     /* From mono.h */
+
+   
 #define SYMBOL_NAME_INTERNAL  "@@"
 
 #define VERB_QUIET    0
