@@ -1,4 +1,4 @@
-/* $Id: mono.c,v 1.10 2010/09/30 11:13:27 bzfkocht Exp $ */
+/* $Id: mono.c,v 1.13 2011/10/25 08:18:02 bzfkocht Exp $ */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*                                                                           */
 /*   File....: mono.c                                                        */
@@ -8,7 +8,7 @@
 /*                                                                           */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*
- * Copyright (C) 2007-2010 by Thorsten Koch <koch@zib.de>
+ * Copyright (C) 2007-2011 by Thorsten Koch <koch@zib.de>
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -22,7 +22,7 @@
  * 
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #include <stdio.h>
@@ -186,7 +186,7 @@ Mono* mono_copy(const Mono* mono)
    return mnew;
 }
      
-void mono_mul_coeff(Mono* mono, const Numb* value)
+void mono_mul_coeff(const Mono* mono, const Numb* value)
 {
    Trace("mono_mul_coeff");
 
@@ -196,7 +196,7 @@ void mono_mul_coeff(Mono* mono, const Numb* value)
    numb_mul(mono->coeff, value);
 }
 
-void mono_add_coeff(Mono* mono, const Numb* value)
+void mono_add_coeff(const Mono* mono, const Numb* value)
 {
    Trace("mono_add_coeff");
 
