@@ -1,4 +1,4 @@
-/* $Id: mshell.h,v 1.11 2010/06/13 12:37:41 bzfkocht Exp $ */
+/* $Id: mshell.h,v 1.14 2011/10/25 08:18:02 bzfkocht Exp $ */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*                                                                           */
 /*   File....: mshell.h                                                      */
@@ -8,7 +8,7 @@
 /*                                                                           */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*
- * Copyright (C) 2007-2010 by Thorsten Koch <koch@zib.de>
+ * Copyright (C) 2007-2011 by Thorsten Koch <koch@zib.de>
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -22,12 +22,16 @@
  * 
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifndef _MSHELL_H_
 #define _MSHELL_H_  
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 /*lint -sem(  mem_malloc, nulterm(2), 1n > 0 && 2p, @P == malloc(1n)) */
 extern void*  mem_malloc(size_t, const char*, const int);
 /*lint -sem(  mem_calloc, nulterm(3), 1n > 0 && 2n > 0 && 3p, @P == malloc(1n * 2n)) */
@@ -79,6 +83,10 @@ extern void   mem_hide_x(void* p, const char* file, const int line);
 
 #endif /* !NO_MSHELL */
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* _MSHELL_H_ */
 
 
