@@ -1,4 +1,4 @@
-/* $Id: numbgmp.c,v 1.34 2010/06/13 12:37:41 bzfkocht Exp $ */
+/* $Id: numbgmp.c,v 1.38 2011/10/25 08:18:02 bzfkocht Exp $ */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*                                                                           */
 /*   File....: numbgmp.c                                                     */
@@ -8,7 +8,7 @@
 /*                                                                           */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*
- * Copyright (C) 2001-2010 by Thorsten Koch <koch@zib.de>
+ * Copyright (C) 2001-2011 by Thorsten Koch <koch@zib.de>
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -22,7 +22,7 @@
  * 
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #include <stdio.h>
@@ -76,6 +76,12 @@ static int        store_count  = 0;
 static Numb* numb_const_zero     = NULL;
 static Numb* numb_const_one      = NULL;
 static Numb* numb_const_minusone = NULL;
+static Numb* numb_const_unknown  = NULL;
+
+/* ??? numb_const_unkown is a hack. GMP has no way to indicate NaN or Infinity.
+ * But we need this for example to convey that the startvalue of a variable has
+ * not been set. 
+ */ 
 
 static void extend_storage(void)
 {
@@ -118,6 +124,7 @@ void numb_init(Bool with_management)
    numb_const_zero     = numb_new();
    numb_const_one      = numb_new_integer(1);
    numb_const_minusone = numb_new_integer(-1);
+   numb_const_unknown  = numb_new_ascii("7e21");
 }
 
 void numb_exit()
@@ -128,10 +135,12 @@ void numb_exit()
    numb_free(numb_const_zero);
    numb_free(numb_const_one);
    numb_free(numb_const_minusone);
+   numb_free(numb_const_unknown);
 
    numb_const_zero     = NULL;
    numb_const_one      = NULL;
    numb_const_minusone = NULL;
+   numb_const_unknown  = NULL;
 
    if (store_count != 0)
       printf("Numb store count %d\n", store_count);
@@ -532,8 +541,13 @@ void numb_round(Numb* numb)
    mpq_init(h);
    mpq_set_d(h, 0.5);
 
-   mpq_add(numb->value.numb, numb->value.numb, h);
-   mpz_fdiv_q(q, mpq_numref(numb->value.numb), mpq_denref(numb->value.numb));
+   /*lint -e(634) Strong type mismatch (type 'Bool') in equality or conditional */
+   if (mpq_sgn(numb->value.numb) >= 0)
+      mpq_add(numb->value.numb, numb->value.numb, h);
+   else
+      mpq_sub(numb->value.numb, numb->value.numb, h);
+
+   mpz_tdiv_q(q, mpq_numref(numb->value.numb), mpq_denref(numb->value.numb));
    mpq_set_z(numb->value.numb, q);
 
    mpz_clear(q);
@@ -573,7 +587,8 @@ Numb* numb_new_log(const Numb* numb)
 
    d = log10(mpq_get_d(numb->value.numb));
 
-   if (!finite(d))
+   /* !finite == !isfinite == isnan || isinf */
+   if (d != d) /*lint !e777 */ /* == isnan(d) || isinf(d) */
    {
       sprintf(temp, "*** Error 700: log(%f)", mpq_get_d(numb->value.numb));
       perror(temp);
@@ -593,7 +608,8 @@ Numb* numb_new_sqrt(const Numb* numb)
 
    d = sqrt(mpq_get_d(numb->value.numb));
 
-   if (!finite(d))
+   /* !finite == !isfinite == isnan || isinf */
+   if (d != d) /*lint !e777 */ /* == isnan(d) || isinf(d) */
    {
       sprintf(temp, "*** Error 701: sqrt(%f)", mpq_get_d(numb->value.numb));
       perror(temp);
@@ -624,7 +640,8 @@ Numb* numb_new_ln(const Numb* numb)
 
    d = log(mpq_get_d(numb->value.numb));
 
-   if (!finite(d))
+   /* !finite == !isfinite == isnan || isinf */
+   if (d != d) /*lint !e777 */ /* == isnan(d) || isinf(d) */
    {
       sprintf(temp, "*** Error 702: ln(%f)", mpq_get_d(numb->value.numb));
       perror(temp);
@@ -734,6 +751,11 @@ const Numb* numb_minusone()
    return numb_const_minusone;
 }
 
+const Numb* numb_unknown()
+{
+   return numb_const_unknown;
+}
+
 Bool numb_is_int(const Numb* numb)
 {
    /* Do we have an integer ?
