@@ -1,4 +1,4 @@
-/* $Id: prog.c,v 1.21 2010/06/13 12:37:41 bzfkocht Exp $ */
+/* $Id: prog.c,v 1.24 2011/10/25 08:18:02 bzfkocht Exp $ */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*                                                                           */
 /*   File....: prog.c                                                        */
@@ -8,7 +8,7 @@
 /*                                                                           */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*
- * Copyright (C) 2001-2010 by Thorsten Koch <koch@zib.de>
+ * Copyright (C) 2001-2011 by Thorsten Koch <koch@zib.de>
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -22,7 +22,7 @@
  * 
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #include <sys/types.h>
@@ -58,6 +58,8 @@
 #define PROG_SID         0x50726f67
 #define PROG_EXTEND_SIZE 100
 
+static void* lp_data = NULL;
+
 struct program
 {
    SID
@@ -67,6 +69,11 @@ struct program
    Stmt**      stmt;
 };
 
+void* prog_get_lp()
+{
+   return lp_data;
+}
+
 Prog* prog_new()
 {
    Prog* prog = calloc(1, sizeof(*prog));
@@ -144,7 +151,7 @@ void prog_print(FILE* fp, const Prog* prog)
       stmt_print(fp, prog->stmt[i]);
 }
 
-void prog_execute(const Prog* prog)
+void prog_execute(const Prog* prog, void* lp)
 {
    int i;
 
@@ -152,6 +159,8 @@ void prog_execute(const Prog* prog)
 
    code_clear_inst_count();
 
+   lp_data = lp;
+
    for(i = 0; i < prog->used; i++)
    {
       stmt_parse(prog->stmt[i]);
