@@ -1,4 +1,4 @@
-/* $Id: random.c,v 1.6 2010/09/30 11:13:28 bzfkocht Exp $ */
+/* $Id: random.c,v 1.8 2011/09/18 10:22:36 bzfkocht Exp $ */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*                                                                           */
 /*   File....: random.c                                                      */
@@ -8,7 +8,7 @@
 /*                                                                           */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*
- * Copyright (C) 2007-2010 by Thorsten Koch <koch@zib.de>
+ * Copyright (C) 2007-2011 by Thorsten Koch <koch@zib.de>
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -22,7 +22,7 @@
  * 
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #include <stdio.h>
@@ -89,9 +89,9 @@
 #define MIXBITS(u,v) (((u) & UMASK) | ((v) & LMASK))
 #define TWIST(u,v)   ((MIXBITS(u,v) >> 1) ^ ((v)&1UL ? MATRIX_A : 0UL))
 
-static unsigned int  state[N]; /* the array for the state vector  */
-static int           left  = 1;
-static unsigned int* next;
+static unsigned int        state[N]; /* the array for the state vector  */
+static int                 left  = 1;
+static const unsigned int* next;
 
 /* initializes state[N] with a seed */
 void rand_init(unsigned long s)
@@ -146,7 +146,6 @@ unsigned int rand_get_int32(void)
 }
 
 /* ----------------------------------------------------------------------------- */
-
 /* Should give a random number between min and max
  */
 int rand_get_range(int mini, int maxi)
