@@ -1,4 +1,4 @@
-/* $Id: random.h,v 1.5 2010/06/13 12:37:41 bzfkocht Exp $ */
+/* $Id: random.h,v 1.8 2011/10/25 08:18:02 bzfkocht Exp $ */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*                                                                           */
 /*   File....: random.h                                                      */
@@ -8,7 +8,7 @@
 /*                                                                           */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*
- * Copyright (C) 2007-2010 by Thorsten Koch <koch@zib.de>
+ * Copyright (C) 2007-2011 by Thorsten Koch <koch@zib.de>
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -22,15 +22,22 @@
  * 
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifndef _RANDOM_H_
 #define _RANDOM_H_
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 extern void         rand_init(unsigned long s);
 extern unsigned int rand_get_int32(void);
 /*lint -sem(        rand_get_range, 1n < 2n) */
 extern int          rand_get_range(int mini, int maxi);
 
+#ifdef __cplusplus
+}
+#endif
 #endif /* RANDOM */
