@@ -1,4 +1,4 @@
-/* $Id: ratlp.h,v 1.23 2010/06/13 12:37:41 bzfkocht Exp $ */
+/* $Id: ratlp.h,v 1.26 2011/10/25 08:18:02 bzfkocht Exp $ */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*                                                                           */
 /*   File....: ratlp.h                                                       */
@@ -8,7 +8,7 @@
 /*                                                                           */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*
- * Copyright (C) 2003-2010 by Thorsten Koch <koch@zib.de>
+ * Copyright (C) 2003-2011 by Thorsten Koch <koch@zib.de>
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -22,7 +22,7 @@
  * 
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 #ifndef _RATLP_H_
 #define _RATLP_H_
@@ -40,6 +40,10 @@
 #error "Need to include mme.h before ratlp.h"
 #endif
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 /* lpstore.c
  */
 /*lint -sem(        lps_alloc, nulterm(1), 1p, @p == 1) */
@@ -184,11 +188,16 @@ extern void         lps_orderfile(const Lps* lp, FILE* fp, LpFormat format, cons
 /*lint -sem(        lps_mstwrite, nulterm(4), 1p == 1 && 2p == 1) */
 extern void         lps_mstfile(const Lps* lp, FILE* fp, LpFormat format, const char* text);
 
+#if 0 /* Not used anymore ??? */
 /* ratpresolve.c
  */
 /*lint -sem(        lps_presolve, 1p == 1 && 2n >= 0) */
 extern PSResult     lps_presolve(Lps* lp, int verbose_level);
-
+#endif
+   
+#ifdef __cplusplus
+}
+#endif
 #endif /* _RATLP_H_ */
 
 
