@@ -1,4 +1,4 @@
-/* $Id: ratlpfwrite.c,v 1.22 2010/09/30 11:13:28 bzfkocht Exp $ */
+/* $Id: ratlpfwrite.c,v 1.25 2011/09/18 10:22:36 bzfkocht Exp $ */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*                                                                           */
 /*   File....: lpfwrite.c                                                    */
@@ -8,7 +8,7 @@
 /*                                                                           */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*
- * Copyright (C) 2003-2010 by Thorsten Koch <koch@zib.de>
+ * Copyright (C) 2003-2011 by Thorsten Koch <koch@zib.de>
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -22,7 +22,7 @@
  * 
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 #include <stdio.h>
 #include <stdlib.h>
@@ -57,8 +57,8 @@ static void permute(int size, void** tab)
    for(i = 0; i < size; i++)
    {
       void* t;
-      int   a = rand_get_range(0, size - 1);
-      int   b = rand_get_range(0, size - 1);
+      int   a = rand_get_range(0, size - 1); /*lint !e426 Call to function violates semantic (1n<2n)*/
+      int   b = rand_get_range(0, size - 1); /*lint !e426 Call to function violates semantic (1n<2n)*/
 
       assert(a >= 0);
       assert(a <  size);
@@ -81,7 +81,7 @@ static void write_val(FILE* fp, LpFormat format, Bool force_sign, const mpq_t va
       fprintf(fp, force_sign ? "%+.15g" : "%.15g", mpq_get_d(val));
       break;
    case LP_FORM_HUM :
-      if (force_sign && (mpq_sgn(val) > 0))
+      if (force_sign && (mpq_sgn(val) > 0)) /*lint !e634 Strong type mismatch (type 'Bool') */
          fprintf(fp, "+");
 
       mpq_out_str(fp, 10, val);
@@ -228,7 +228,7 @@ static void write_row(
       }
       if (format == LP_FORM_LPF || format == LP_FORM_RLP)
       {
-         fprintf(fp,  " ]/2\n");
+         fprintf(fp,  " ]\n");
          cnt = 0;
       }
    }
@@ -241,9 +241,12 @@ static void write_row(
 
       if (format != LP_FORM_PIP)
       {
-         fprintf(stderr, "--- Warning 600: File format can only handle linear and quadratic constraints\n");
-         fprintf(stderr, "                 Constraint %s with degree %d ignored\n", 
-            con->name, term_get_degree(term));
+         if (verbose > 0)
+         {
+            fprintf(stderr, "--- Warning 600: File format can only handle linear and quadratic constraints\n");
+            fprintf(stderr, "                 Constraint %s with degree %d ignored\n", 
+               con->name, term_get_degree(term));
+         }
          only_comment = TRUE;
       }
       assert(numb_equal(term_get_constant(term), numb_zero()));
