@@ -1,4 +1,4 @@
-/* $Id: ratlpstore.c,v 1.37 2010/06/13 12:37:41 bzfkocht Exp $ */
+/* $Id: ratlpstore.c,v 1.40 2011/10/25 08:18:02 bzfkocht Exp $ */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*                                                                           */
 /*   File....: lpstore.c                                                     */
@@ -8,7 +8,7 @@
 /*                                                                           */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*
- * Copyright (C) 2003-2010 by Thorsten Koch <koch@zib.de>
+ * Copyright (C) 2003-2011 by Thorsten Koch <koch@zib.de>
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -22,7 +22,7 @@
  * 
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 #include <stdio.h>
 #include <stdlib.h>
@@ -45,6 +45,10 @@
 #include "ratlp.h"
 #include "ratlpstore.h"
 
+#ifdef _MSC_VER
+#pragma warning (disable: 4100)
+#endif
+
 #define LPF_NAME_LEN  16
 #define MPS_NAME_LEN  8
 #define PIP_NAME_LEN  255
@@ -1143,7 +1147,7 @@ void lps_delcon(
 
    lp->cons--;
    
-   //??? qme_first  term ?
+   /* ??? qme_first  term ? */
 
    assert(lps_valid(lp));
 }
