@@ -1,4 +1,4 @@
-/* $Id: ratlpstore.h,v 1.19 2010/06/13 12:37:41 bzfkocht Exp $ */
+/* $Id: ratlpstore.h,v 1.22 2011/10/25 08:18:02 bzfkocht Exp $ */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*                                                                           */
 /*   File....: ratlpstore.h                                                  */
@@ -8,7 +8,7 @@
 /*                                                                           */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*
- * Copyright (C) 2003-2010 by Thorsten Koch <koch@zib.de>
+ * Copyright (C) 2003-2011 by Thorsten Koch <koch@zib.de>
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -22,7 +22,7 @@
  * 
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifndef _RATLPSTORE_H_
@@ -38,6 +38,10 @@
 #error "Need to include ratlptypes.h before ratlpstore.h"
 #endif
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 typedef struct storage Sto;
 
 typedef struct lps_hash LpsHash;
@@ -163,6 +167,9 @@ int                 lps_getnamesize(const Lps* lp, LpFormat format);
 /*lint -sem(        lps_makename, nulterm(3), 1p && 2n > 0 && 3p && 4n >= -1) */
 void                lps_makename(char* target, int size, const char* name, int no);
 
+#ifdef __cplusplus
+}
+#endif
 #endif /* _RATLPSTORE_H_ */
 
 
