@@ -1,4 +1,4 @@
-/* $Id: ratlptypes.h,v 1.12 2010/06/13 12:37:41 bzfkocht Exp $ */
+/* $Id: ratlptypes.h,v 1.15 2011/10/25 08:18:02 bzfkocht Exp $ */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*                                                                           */
 /*   File....: ratlptypes.h                                                  */
@@ -8,7 +8,7 @@
 /*                                                                           */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*
- * Copyright (C) 2003-2010 by Thorsten Koch <koch@zib.de>
+ * Copyright (C) 2003-2011 by Thorsten Koch <koch@zib.de>
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -22,7 +22,7 @@
  * 
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 #ifndef _RATLPTYPES_H_
 #define _RATLPTYPES_H_
@@ -31,6 +31,10 @@
 #error "Need to include bool.h before ratlp.h"
 #endif
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 enum con_type        { CON_FREE    = 0, CON_LHS,   CON_RHS,   CON_RANGE, CON_EQUAL };
 enum var_type        { VAR_FREE    = 0, VAR_LOWER, VAR_UPPER, VAR_BOXED, VAR_FIXED };
 enum sos_type        { SOS_ERR     = 0, SOS_TYPE1, SOS_TYPE2 };
@@ -38,12 +42,17 @@ enum var_class       { VAR_CON     = 0, VAR_IMP,   VAR_INT };
 enum lp_direct       { LP_MIN      = 0, LP_MAX };
 enum lp_type         { LP_ERR      = 0, LP_LP, LP_IP };
 enum lp_format       { LP_FORM_ERR = 0, LP_FORM_LPF, LP_FORM_HUM, LP_FORM_MPS, LP_FORM_RLP, LP_FORM_PIP };
+
+#if 0 /* not used anymore ??? */
 enum presolve_result
 {
    PRESOLVE_ERROR = 0, PRESOLVE_OKAY, PRESOLVE_INFEASIBLE,
    PRESOLVE_UNBOUNDED, PRESOLVE_VANISHED
 };
+typedef enum presolve_result PSResult;
 
+#endif
+   
 typedef struct nonzero       Nzo;
 typedef struct variable      Var;
 typedef struct constraint    Con;
@@ -52,7 +61,6 @@ typedef struct soselement    Sse;
 typedef struct qmatentry     Qme;
 typedef struct lpstorage     Lps;
 
-typedef enum   var_type      VarType;
 typedef enum   con_type      ConType;
 typedef enum   sos_type      SosType;
 typedef enum   var_class     VarClass;
@@ -60,8 +68,6 @@ typedef enum   lp_direct     LpDirect;
 typedef enum   lp_type       LpType;
 typedef enum   lp_format     LpFormat;
 
-typedef enum presolve_result PSResult;
-
 #define LP_FLAG_CON_SCALE    0x01
 #define LP_FLAG_CON_SEPAR    0x02
 #define LP_FLAG_CON_CHECK    0x04
@@ -72,4 +78,7 @@ typedef enum presolve_result PSResult;
 #define HAS_LHS(con)    ((con)->type != CON_FREE && (con)->type != CON_RHS)
 #define HAS_RHS(con)    ((con)->type != CON_FREE && (con)->type != CON_LHS)
 
+#ifdef __cplusplus
+}
+#endif
 #endif /* _RATLPTYPES_H_ */
