@@ -1,4 +1,4 @@
-/* $Id: ratpresolve.c,v 1.13 2010/06/13 12:37:41 bzfkocht Exp $ */
+/* $Id: ratpresolve.c,v 1.16 2011/10/25 08:18:02 bzfkocht Exp $ */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*                                                                           */
 /*   File....: lpstore.c                                                     */
@@ -8,7 +8,7 @@
 /*                                                                           */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*
- * Copyright (C) 2003-2010 by Thorsten Koch <koch@zib.de>
+ * Copyright (C) 2003-2011 by Thorsten Koch <koch@zib.de>
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -22,8 +22,9 @@
  * 
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
+#if 0 /* Not used anymore ??? */
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -640,11 +641,5 @@ PSResult lps_presolve(Lps* lp, int verbose_level)
    return ret;
 }
 
-/* ------------------------------------------------------------------------- */
-/* Emacs Local Variables:                                                    */
-/* Emacs mode:c                                                              */
-/* Emacs c-basic-offset:3                                                    */
-/* Emacs tab-width:8                                                         */
-/* Emacs indent-tabs-mode:nil                                                */
-/* Emacs End:                                                                */
-/* ------------------------------------------------------------------------- */
+#endif
+
