@@ -1,4 +1,4 @@
-/* $Id: set4.h,v 1.16 2010/06/13 12:37:41 bzfkocht Exp $ */
+/* $Id: set4.h,v 1.19 2011/10/25 08:18:02 bzfkocht Exp $ */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*                                                                           */
 /*   File....: set4.h                                                        */
@@ -8,7 +8,7 @@
 /*                                                                           */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*
- * Copyright (C) 2001-2010 by Thorsten Koch <koch@zib.de>
+ * Copyright (C) 2001-2011 by Thorsten Koch <koch@zib.de>
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -22,12 +22,15 @@
  * 
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
-
 #ifndef _SET4_H_
 #define _SET4_H_
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 enum set_type {
    SET_ERROR   =  0,
    SET_EMPTY   =  1, /* dim = ?, Empty Set */
@@ -263,6 +266,9 @@ extern void         set_multi_init(SetVTab* vtab);
 /*lint -sem(        set_multi_new_from_list, 1p == 1, @p == 1) */
 extern Set*         set_multi_new_from_list(const List* list, SetCheckType check);
 
+#ifdef __cplusplus
+}
+#endif
 #endif /* _SET4_H_ */
 
 
