@@ -1,4 +1,4 @@
-/* $Id: setmulti.c,v 1.20 2010/06/13 12:37:41 bzfkocht Exp $ */
+/* $Id: setmulti.c,v 1.25 2011/10/25 08:18:02 bzfkocht Exp $ */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*                                                                           */
 /*   File....: setmulti.c                                                    */
@@ -8,7 +8,7 @@
 /*                                                                           */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*
- * Copyright (C) 2001-2010 by Thorsten Koch <koch@zib.de>
+ * Copyright (C) 2001-2011 by Thorsten Koch <koch@zib.de>
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -22,7 +22,7 @@
  * 
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #include <stddef.h>
@@ -42,8 +42,12 @@
 #include "list.h"
 #include "hash.h"
 #include "stmt.h"
-#include "set4.h"
 #include "set.h"
+#include "set4.h"
+
+#ifdef _MSC_VER
+#pragma warning (disable: 4100) /* unreferenced formal parameter */
+#endif
 
 #define SET_MULTI_SID          0x5345544d
 #define SET_MULTI_ITER_SID     0x53454d49
@@ -177,8 +181,9 @@ Set* set_multi_new_from_list(const List* list, SetCheckType check)
          ? entry_get_tuple(list_get_entry(list, &le))
          : list_get_tuple(list, &le);
 
+      assert(tuple != NULL);
       assert(hash != NULL || check == SET_CHECK_NONE);
-      
+
       if (hash != NULL && hash_has_tuple(hash, tuple))
       {
          if (check == SET_CHECK_WARN)
