@@ -1,4 +1,4 @@
-/* $Id: zimpllib.h,v 1.9 2010/06/13 12:37:41 bzfkocht Exp $ */
+/* $Id: zimpllib.h,v 1.12 2011/10/25 08:18:02 bzfkocht Exp $ */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*                                                                           */
 /*   File....: zimpllib.h                                                    */
@@ -8,7 +8,7 @@
 /*                                                                           */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*
- * Copyright (C) 2005-2010 by Thorsten Koch <koch@zib.de>
+ * Copyright (C) 2005-2011 by Thorsten Koch <koch@zib.de>
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -22,7 +22,7 @@
  * 
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 #ifndef _ZIMPLLIB_H_
 #define _ZIMPLLIB_H_
@@ -43,9 +43,9 @@ extern void         zpl_var_print(FILE* fp, const Var* var);
 extern void         zpl_print_banner(FILE* fp, Bool with_license);
 
 /*lint -sem(zpl_read, nulterm(1)) */
-extern Bool         zpl_read(const char* filename, Bool with_management);
+extern Bool         zpl_read(const char* filename, Bool with_management, void* user_data);
 /*lint -sem(zpl_read_with_args, 1n > 0 && 2p) */
-extern Bool         zpl_read_with_args(char** argv, int argc, Bool with_management);
+extern Bool         zpl_read_with_args(char** argv, int argc, Bool with_management, void* user_data);
 
 #ifdef __cplusplus
 }
